@@ -30,7 +30,7 @@ from starfishX.peterlynch.balancesheet import getAssets
 from starfishX.peterlynch.balancesheet import getLiabilities    
 
 from starfishX.peterlynch.fcf import getFreeCashFlow
-
+from starfishX.peterlynch.fcf import getFreeCashFlowWSJ  #0.4 update
 
 #ส่วนของการวิเคราะห์อุตสาหกรรม
 from starfishX.peterlynch.industrial import getYoY  
@@ -49,4 +49,4 @@ from starfishX.peterlynch.pehistory import getPEHistory
 
 from starfishX.peterlynch.sixclass import findGrowth
 
-__version__ = "peterlynch 0.1"
\ No newline at end of file
+__version__ = "peterlynch 0.4" #19 สิงหาคม 2564 update 0.3
\ No newline at end of file
