@@ -1953,7 +1953,71 @@ def getohlc(symbol):
 
 
 # ==============================
-def getMemberOfIndex(indexType):
+from urllib.request import urlopen
+def getMemberOfIndex(indexType):  #2022-10-22 UpdateVersion 
+ '''
+    arg1 (indexMarket): ตัวอย่างเช่น sx.indexMarket.SET50 ประกอบด้วย SET50,SET100,sSET,SETCLMV,SETHD,SETTHSI,SETWB 
+           
+    Returns (dataFrame) 
+ ''' 
+ if(not isinstance(indexType, indexMarket)):
+    print("Data Type indexMarket Not Match")
+    return 0
+  
+ symbol = indexType.value
+
+ if(symbol=="SET"):
+   print("SET NOT Support ,หรืออาจใช้ sx.listSecurities เรียกใช้แทน")
+   return 0
+ 
+ indexType = indexType.value
+ url = 'https://www.set.or.th/api/set/index/'+indexType+'/composition?lang=th'
+ url = url.lower() 
+ 
+ response = urlopen(url)
+  
+ # storing the JSON response 
+ # from url in data
+ data_json = json.loads(response.read())
+ 
+ m = pd.DataFrame(data_json['composition']['stockInfos'])['symbol'].values
+ return m
+
+def getDividendYieldOfIndex(indexType):  #2022-10-22 UpdateVersion 
+ '''
+    arg1 (indexMarket): ตัวอย่างเช่น sx.indexMarket.SET50 ประกอบด้วย SET50,SET100,sSET,SETCLMV,SETHD,SETTHSI,SETWB 
+           
+    Returns (dataFrame) 
+ ''' 
+ if(not isinstance(indexType, indexMarket)):
+    print("Data Type indexMarket Not Match")
+    return 0
+  
+ symbol = indexType.value
+
+ if(symbol=="SET"):
+   print("SET NOT Support ,หรืออาจใช้ sx.listSecurities เรียกใช้แทน")
+   return 0
+ 
+ indexType = indexType.value
+ url = 'https://www.set.or.th/api/set/index/'+indexType+'/composition?lang=th'
+ url = url.lower() 
+ 
+ response = urlopen(url)
+  
+ # storing the JSON response 
+ # from url in data
+ data_json = json.loads(response.read())
+ 
+ m = pd.DataFrame(data_json['composition']['stockInfos'])#['symbol'].values
+ m = m.set_index('symbol')
+ #m = m.sort_values('dividendYield')['dividendYield']
+ return m[['dividendYield']]
+ 
+
+
+
+def getMemberOfIndex_deprecated(indexType):
  '''
     arg1 (indexMarket): ตัวอย่างเช่น sx.indexMarket.SET50 ประกอบด้วย SET50,SET100,sSET,SETCLMV,SETHD,SETTHSI,SETWB 
            
