@@ -10,7 +10,8 @@ import seaborn as sns
 
 ################## ดึงข้อมูลจากตลาดหลักทรัพย์ ################
 import requests
-
+from PIL import Image
+from io import BytesIO
 def getURL(symbol,typeurl):
     if(typeurl=='trading-stat'):
        return  'https://www.set.or.th/api/set/stock/'+symbol+'/company-highlight/trading-stat?lang=th'
@@ -83,6 +84,34 @@ def getIndustry():
   data = data[data['querySector']!='']
   data = data.groupby(['industry','querySector']).mean()
   return data
+
+def barChartWithLogo(symbol,values,title,figsize=(12,8)):
+  plt.rcParams["figure.figsize"] = figsize 
+  height = 2
+  plt.subplots(facecolor='white')
+  plt.bar(x=symbol, height=values, align='center')
+
+  for i, (label, value) in enumerate(zip(symbol, values)):
+   try:
+      #print(label)  
+      url = 'https://media.set.or.th/common/logo/company/'+label+'.png'
+      #print(url)
+      response = requests.get(url)
+      #img = plt.imread(BytesIO(response.content))
+      response = requests.get(url)
+      img = Image.open(BytesIO(response.content))
+      #print(i,value,height)
+      plt.imshow(img, extent=[(i - height / 8), (i + height / 8),value*1.05, ((value/2)+(value*1.1))], aspect='auto', zorder=2)
+   except:
+      pass
+    
+
+  plt.title(title)
+  plt.xlim(-1, len(symbol) + 1)
+  plt.ylim(2, max(values) *2)
+  plt.tight_layout()
+
+  plt.show()
 ################## End ดึงข้อมูลจากตลาดหลักทรัพย์ ################
 
 
